@@ -7,7 +7,7 @@ require(smooth)
 require(Mcomp)
 
 ## ----sma_N2457-----------------------------------------------------------
-sma(M3$N2457$x, h=18)
+sma(M3$N2457$x, h=18, silent=FALSE)
 
 ## ----sma_N2568-----------------------------------------------------------
 sma(M3$N2568$x, h=18)
