@@ -1,5 +1,5 @@
 ## ----global_options, include=FALSE---------------------------------------
-knitr::opts_chunk$set(fig.width=6, fig.height=4, fig.path='Figs/', fig.show='hold',
+knitr::opts_chunk$set(fig.width=6, fig.height=5.5, fig.path='Figs/', fig.show='hold',
                       warning=FALSE, message=FALSE)
 
 ## ----load_libraries, message=FALSE, warning=FALSE------------------------
